# PyDonno

This is a single PyPI package to install all my packages.

## To use

Just install the package.

### From PyPI

`py -m pip install PyDonno`

### From GitHub

`py -m pip install git+https://github.com/donno2048/PyDonno`
